@@ -1,4 +1,5 @@
 # -*- coding: UTF-8 -*-
+# vim: expandtab sw=4 ts=4 sts=4:
 '''
 Wammu - Phone manager
 About dialog
@@ -6,7 +7,7 @@ About dialog
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright (c) 2003 - 2006 Michal Čihař
+Copyright (c) 2003 - 2007 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -30,21 +31,18 @@ import Wammu
 if Wammu.gammu_error == None:
     import gammu
 import Wammu.Utils
-from Wammu.Paths import *
-from Wammu.Utils import HtmlStr_ as _, HtmlStrConv
+import Wammu.Paths
+from Wammu.Locales import hgettext as _, HtmlStrConv
 
 class AboutBox(wx.Dialog):
+    '''
+    Displays box showing information about program including versions of used
+    components.
+    '''
     def __init__(self, parent):
         wx.Dialog.__init__(self, parent, -1, _('About Wammu'))
 
-        if wx.USE_UNICODE:
-            copyrightline = u'Copyright &copy; 2003 - 2006 Michal Čihař'
-            head = ''
-        else:
-            copyrightline = HtmlStrConv(u'Copyright (c) 2003 - 2006 Michal Čihař')
-            if copyrightline.find('?') != -1:
-                copyrightline = 'Copyright (c) 2003 - 2006 Michal Cihar'
-            head = '<head><meta http-equiv="Content-Type" content="text/html; charset=%s"></head>' % Wammu.Utils.htmlcharset
+        copyrightline = u'Copyright &copy; 2003 - 2007 Michal Čihař'
 
         # default system colours
         bgc = wx.SystemSettings.GetColour(wx.SYS_COLOUR_BTNFACE)
@@ -58,7 +56,6 @@ class AboutBox(wx.Dialog):
 
         text = '''
 <html>
-%s
 <body %s>
 <center><font color="#ffffff"><table bgcolor="#458154" width="100%%" cellspacing="0"
 cellpadding="0" border="1">
@@ -82,7 +79,6 @@ cellpadding="0" border="1">
 </p>
 <p>
 <wxp module="wx" class="Button">
-    <param name="label" value="%s">
     <param name="id"    value="ID_OK">
 </wxp>
 </p>
@@ -90,11 +86,11 @@ cellpadding="0" border="1">
 </body>
 </html>
 
-''' % (head, colours, '''<img src="%s"><br><h2> Wammu %s</h2>
+''' % (colours, '''<img src="%s"><br><h2> Wammu %s</h2>
     %s<br>
     %s<br>
     %s<br>
-''' % (AppIconPath('wammu'),
+''' % (Wammu.Paths.AppIconPath('wammu'),
             Wammu.__version__,
             _('Running on Python %s') % sys.version.split()[0],
             _('Using wxPython %s') % wx.VERSION_STRING,
@@ -115,15 +111,14 @@ This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
-'''),
-            _('OK'))
+'''))
 
         html = wx.html.HtmlWindow(self, -1, size = (500, -1))
         html.SetPage(text)
         btn = html.FindWindowById(wx.ID_OK)
         if btn != None:
             btn.SetDefault()
-        ir = html.GetInternalRepresentation()
-        html.SetSize( (ir.GetWidth()+25, ir.GetHeight()+25) )
+        representation = html.GetInternalRepresentation()
+        html.SetSize( (representation.GetWidth()+25, representation.GetHeight()+25) )
         self.SetClientSize(html.GetSize())
         self.CentreOnParent(wx.BOTH)
