@@ -1,4 +1,5 @@
 # -*- coding: UTF-8 -*-
+# vim: expandtab sw=4 ts=4 sts=4:
 '''
 Wammu - Phone manager
 SMS composer
@@ -6,7 +7,7 @@ SMS composer
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright (c) 2003 - 2006 Michal Čihař
+Copyright (c) 2003 - 2007 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -31,35 +32,30 @@ import Wammu.MessageDisplay
 import Wammu.Utils
 import Wammu.PhoneValidator
 import Wammu.Select
+import Wammu.EditContactList
 if Wammu.gammu_error == None:
     import gammu
 import locale
-from Wammu.Utils import UnicodeConv, Str_ as _
-
-if wx.USE_UNICODE:
-    htmlhead = ''
-else:
-    htmlhead = '<head><meta http-equiv="Content-Type" content="text/html; charset=%s"></head>' % Wammu.Utils.htmlcharset
+import Wammu.Locales
 
 class MessagePreview(wx.Dialog):
     text = '''
 <html>
-%s
 <body>
 %s
 <center>
 <p><wxp module="wx" class="Button">
-    <param name="label" value="%s">
     <param name="id"    value="ID_OK">
 </wxp></p>
 </center>
 </body>
 </html>
 '''
+
     def __init__(self, parent, content):
         wx.Dialog.__init__(self, parent, -1, _('Message preview'))
         html = wx.html.HtmlWindow(self, -1, size=(420, -1))
-        html.SetPage(self.text % (htmlhead, content, _('OK')))
+        html.SetPage(self.text % content)
         btn = html.FindWindowById(wx.ID_OK)
         btn.SetDefault()
         ir = html.GetInternalRepresentation()
@@ -119,7 +115,7 @@ class StyleEdit(wx.Dialog):
             maxcol = max(col, maxcol)
             col = 1
 
-        self.ok = wx.Button(self, wx.ID_OK, _('OK'))
+        self.ok = wx.Button(self, wx.ID_OK)
         self.sizer.Add(self.ok, pos = (row, 1), span = wx.GBSpan(colspan = maxcol), flag = wx.ALIGN_CENTER)
         wx.EVT_BUTTON(self, wx.ID_OK, self.Okay)
 
@@ -172,14 +168,14 @@ class TextEditor(GenericEditor):
         self.concat.SetToolTipString(_('Create concatenated message, what allows to send longer messages.'))
         self.concat.SetValue(self.part['ID'] != 'Text')
         wx.EVT_CHECKBOX(self.concat, self.concat.GetId(), self.OnConcatChange)
-        self.sizer.Add(self.concat, pos = (1, 0))
+        self.sizer.Add(self.concat, pos = (1, 0), flag = wx.ALIGN_CENTER_VERTICAL)
 
-        self.leninfo = wx.StaticText(self, -1, _('%d chars') % 999)
+        self.leninfo = wx.StaticText(self, -1, '')
         self.sizer.Add(self.leninfo, pos = (1, 3), flag = wx.ALIGN_RIGHT)
 
         self.stylebut = wx.Button(self, -1, _('Style'))
         wx.EVT_BUTTON(self, self.stylebut.GetId(), self.StylePressed)
-        self.sizer.Add(self.stylebut, pos = (1, 1))
+        self.sizer.Add(self.stylebut, pos = (1, 1), flag = wx.ALIGN_CENTER)
 
         self.OnConcatChange()
 
@@ -190,6 +186,7 @@ class TextEditor(GenericEditor):
         self.sizer.Fit(self)
         self.SetAutoLayout(True)
         self.SetSizer(self.sizer)
+        self.TextChanged()
 
     def OnUnicode(self, newu):
         self.unicode = newu
@@ -217,18 +214,20 @@ class TextEditor(GenericEditor):
         if not self.concat.GetValue() and ((self.unicode and length > 70) or (not self.unicode and length > 160)):
             self.edit.SetValue(self.backuptext)
             return
-        self.leninfo.SetLabel( _('%d chars') % len(self.edit.GetValue()))
+        length = len(self.edit.GetValue())
+        self.leninfo.SetLabel(Wammu.Locales.ngettext('%d char', '%d chars', length) % length)
+        self.sizer.Layout()
         self.backuptext = txt
 
     def GetValue(self):
         if self.concat.GetValue():
-            if self.cfg.Read('/Message/16bitId', 'yes') == 'yes':
+            if self.cfg.Read('/Message/16bitId') == 'yes':
                 self.part['ID'] = 'ConcatenatedTextLong16bit'
             else:
                 self.part['ID'] = 'ConcatenatedTextLong'
         else:
             self.part['ID'] = 'Text'
-        self.part['Buffer'] = UnicodeConv(self.edit.GetValue())
+        self.part['Buffer'] = Wammu.Locales.UnicodeConv(self.edit.GetValue())
         return self.part
 
 class PredefinedAnimEditor(GenericEditor):
@@ -241,6 +240,7 @@ class PredefinedAnimEditor(GenericEditor):
             values.append(x[0])
 
         self.sizer.AddGrowableRow(0)
+        self.sizer.AddGrowableCol(0)
         self.sizer.AddGrowableCol(1)
         self.sizer.AddGrowableCol(2)
 
@@ -257,7 +257,7 @@ class PredefinedAnimEditor(GenericEditor):
         self.edit.SetSelection(self.part['Number'])
         self.OnChange()
 
-        self.sizer.Add(wx.StaticText(self, -1, _('Select predefined animation:')), pos = (0,0), flag = wx.ALIGN_CENTER_VERTICAL | wx.EXPAND)
+        self.sizer.Add(wx.StaticText(self, -1, _('Select predefined animation:')), pos = (0,0), flag = wx.ALIGN_CENTER_VERTICAL)
         self.sizer.Add(self.edit, pos = (0,1), flag = wx.ALIGN_CENTER)
         self.sizer.Add(self.bitmap, pos = (0,2), flag = wx.ALIGN_CENTER)
 
@@ -284,6 +284,7 @@ class PredefinedSoundEditor(GenericEditor):
             values.append(x[0])
 
         self.sizer.AddGrowableRow(0)
+        self.sizer.AddGrowableCol(0)
         self.sizer.AddGrowableCol(1)
 
         self.edit = wx.Choice(self, -1, choices = values)
@@ -322,8 +323,8 @@ class SMSComposer(wx.Dialog):
         if not entry.has_key('SMSInfo'):
             entry['SMSInfo'] = {}
             entry['SMSInfo']['Entries'] = []
-            if self.cfg.Read('/Message/Concatenated', 'yes') == 'yes':
-                if self.cfg.Read('/Message/16bitId', 'yes') == 'yes':
+            if self.cfg.Read('/Message/Concatenated') == 'yes':
+                if self.cfg.Read('/Message/16bitId') == 'yes':
                     typ = 'ConcatenatedTextLong16bit'
                 else:
                     typ = 'ConcatenatedTextLong'
@@ -352,10 +353,10 @@ class SMSComposer(wx.Dialog):
         self.save.SetToolTipString(_('When checked, message is saved to phone.'))
         self.save.SetValue(action == 'save')
 
-        wx.EVT_CHECKBOX(self.save, self.save.GetId(), self.OnSave)
-        wx.EVT_CHECKBOX(self.send, self.send.GetId(), self.OnSend)
+        self.Bind(wx.EVT_CHECKBOX, self.OnSave, self.save)
+        self.Bind(wx.EVT_CHECKBOX, self.OnSend, self.send)
 
-        self.folder = wx.SpinCtrl(self, -1, '2', style = wx.SP_WRAP|wx.SP_ARROW_KEYS , min = 0, max = 3, initial = 2)
+        self.folder = wx.SpinCtrl(self, -1, '2', style = wx.SP_WRAP|wx.SP_ARROW_KEYS , min = 0, max = 100, initial = 2)
 
         self.sizer.Add(self.send, pos = (row,1), flag = wx.ALIGN_LEFT)
         self.sizer.Add(self.save, pos = (row,6), flag = wx.ALIGN_LEFT)
@@ -363,15 +364,20 @@ class SMSComposer(wx.Dialog):
 
         row = row + 2
 
-        self.number = wx.TextCtrl(self, -1, entry['Number'], validator = Wammu.PhoneValidator.PhoneValidator(multi = True))
-        self.contbut = wx.Button(self, -1, _('Contacts'))
+        self.number = wx.TextCtrl(self, -1, entry['Number'], validator = Wammu.PhoneValidator.PhoneValidator(multi = True), size = (150, -1))
+        self.contbut = wx.Button(self, -1, _('Add'))
         self.contbut.SetToolTipString(_('Add number of recipient from contacts.'))
+        # TODO: when switching to wx 2.8, use wx.ID_EDIT
+        self.editlistbut = wx.Button(self, -1, _('Edit'))
+        self.editlistbut.SetToolTipString(_('Edit recipients list.'))
 
-        self.sizer.Add(wx.StaticText(self, -1, _('Recipient\'s numbers:')), pos = (row,1), flag = wx.ALIGN_LEFT)
-        self.sizer.Add(self.number, pos = (row,2), flag = wx.EXPAND, span = wx.GBSpan(colspan = 5))
+        self.sizer.Add(wx.StaticText(self, -1, _('Recipient\'s numbers:')), pos = (row,1), flag = wx.ALIGN_LEFT | wx.ALIGN_CENTER_VERTICAL)
+        self.sizer.Add(self.number, pos = (row,2), flag = wx.ALIGN_CENTER_VERTICAL | wx.EXPAND, span = wx.GBSpan(colspan = 4))
+        self.sizer.Add(self.editlistbut, pos = (row,6), flag = wx.ALIGN_CENTER)
         self.sizer.Add(self.contbut, pos = (row,7), flag = wx.ALIGN_CENTER)
 
-        wx.EVT_BUTTON(self, self.contbut.GetId(), self.ContactPressed)
+        self.Bind(wx.EVT_BUTTON, self.ContactPressed, self.contbut)
+        self.Bind(wx.EVT_BUTTON, self.EditContactPressed, self.editlistbut)
 
         row = row + 2
 
@@ -380,15 +386,15 @@ class SMSComposer(wx.Dialog):
         if self.entry.has_key('Unicode'):
             self.unicode.SetValue(self.entry['Unicode'])
         else:
-            self.unicode.SetValue(self.cfg.Read('/Message/Unicode', 'no') == 'yes')
+            self.unicode.SetValue(self.cfg.Read('/Message/Unicode') == 'yes')
 
         self.sizer.Add(self.unicode, pos = (row,1), flag = wx.ALIGN_LEFT)
 
-        wx.EVT_CHECKBOX(self.unicode, self.unicode.GetId(), self.OnUnicode)
+        self.Bind(wx.EVT_CHECKBOX, self.OnUnicode, self.unicode)
 
         self.report = wx.CheckBox(self, -1, _('Delivery report'))
         self.report.SetToolTipString(_('Check to request delivery report for message.'))
-        self.report.SetValue(self.cfg.Read('/Message/DeliveryReport', 'no') == 'yes')
+        self.report.SetValue(self.cfg.Read('/Message/DeliveryReport') == 'yes')
         self.sizer.Add(self.report, pos = (row,2), flag = wx.ALIGN_LEFT)
 
         self.sent = wx.CheckBox(self, -1, _('Sent'))
@@ -407,10 +413,11 @@ class SMSComposer(wx.Dialog):
         self.available = AutoSizeList(self, _('Available message parts'))
         # FIXME: add icons?
 
-        self.addbut = wx.Button(self, -1, _('<<< Add <<<'))
-        self.delbut = wx.Button(self, -1, _('>>> Delete'))
-        wx.EVT_BUTTON(self, self.addbut.GetId(), self.AddPressed)
-        wx.EVT_BUTTON(self, self.delbut.GetId(), self.DeletePressed)
+        self.addbut = wx.Button(self, wx.ID_ADD)
+        self.delbut = wx.Button(self, wx.ID_REMOVE)
+
+        self.Bind(wx.EVT_BUTTON, self.AddPressed, self.addbut)
+        self.Bind(wx.EVT_BUTTON, self.DeletePressed, self.delbut)
 
         self.sizer.Add(self.current, pos = (row,1), flag = wx.EXPAND, span = wx.GBSpan(colspan = 2, rowspan = 2))
         self.sizer.Add(self.addbut, pos = (row,4), flag = wx.ALIGN_CENTER)
@@ -419,14 +426,14 @@ class SMSComposer(wx.Dialog):
 
         row = row + 3
 
-        self.upbut = wx.Button(self, -1, _('Up'))
-        self.dnbut = wx.Button(self, -1, _('Down'))
+        self.upbut = wx.Button(self, wx.ID_UP)
+        self.dnbut = wx.Button(self, wx.ID_DOWN)
 
         self.sizer.Add(self.upbut, pos = (row,1), flag = wx.ALIGN_CENTER)
         self.sizer.Add(self.dnbut, pos = (row,2), flag = wx.ALIGN_CENTER)
 
-        wx.EVT_BUTTON(self, self.upbut.GetId(), self.UpPressed)
-        wx.EVT_BUTTON(self, self.dnbut.GetId(), self.DnPressed)
+        self.Bind(wx.EVT_BUTTON, self.UpPressed, self.upbut)
+        self.Bind(wx.EVT_BUTTON, self.DnPressed, self.dnbut)
 
         row = row + 2
         self.sizer.AddGrowableRow(row)
@@ -437,17 +444,16 @@ class SMSComposer(wx.Dialog):
 
         row = row + 2
 
-        self.ok = wx.Button(self, wx.ID_OK, _('OK'))
-        self.cancel = wx.Button(self, wx.ID_CANCEL, _('Cancel'))
         self.preview = wx.Button(self, -1, _('Preview'))
-#        self.advanced = wx.Button(self, -1, _('Advanced'))
-        self.sizer.Add(self.ok, pos = (row, 1), flag = wx.ALIGN_CENTER)
-        self.sizer.Add(self.cancel, pos = (row, 2), flag = wx.ALIGN_CENTER)
-        self.sizer.Add(self.preview, pos = (row, 6), flag = wx.ALIGN_CENTER)
-#        self.sizer.Add(self.advanced, pos = (row, 7), flag = wx.ALIGN_CENTER)
+        self.button_sizer = wx.StdDialogButtonSizer()
+        self.button_sizer.AddButton(wx.Button(self, wx.ID_OK))
+        self.button_sizer.AddButton(wx.Button(self, wx.ID_CANCEL))
+        self.button_sizer.SetNegativeButton(self.preview)
+        self.button_sizer.Realize()
+        self.sizer.Add(self.button_sizer, pos = (row, 1), span = wx.GBSpan(colspan = 7), flag = wx.ALIGN_RIGHT)
 
-        wx.EVT_BUTTON(self, wx.ID_OK, self.Okay)
-        wx.EVT_BUTTON(self, self.preview.GetId(), self.Preview)
+        self.Bind(wx.EVT_BUTTON, self.Okay, id = wx.ID_OK)
+        self.Bind(wx.EVT_BUTTON, self.Preview, self.preview)
 
         self.sizer.AddSpacer((5,5), pos=(row + 1,8))
         self.sizer.AddGrowableCol(1)
@@ -461,8 +467,8 @@ class SMSComposer(wx.Dialog):
         self.prevedit = -1
         self.availsel = -1
 
-        wx.EVT_LIST_ITEM_SELECTED(self.current, self.current.GetId(), self.CurrentSelected)
-        wx.EVT_LIST_ITEM_SELECTED(self.available, self.available.GetId(), self.AvailableSelected)
+        self.Bind(wx.EVT_LIST_ITEM_SELECTED, self.CurrentSelected, self.current)
+        self.Bind(wx.EVT_LIST_ITEM_SELECTED, self.AvailableSelected, self.available)
 
         if action == 'send':
             self.OnSave()
@@ -480,6 +486,16 @@ class SMSComposer(wx.Dialog):
         if v != None:
             self.number.SetValue(self.number.GetValue() + ' ' + v)
 
+    def EditContactPressed(self, evt):
+        '''
+        Opens dialog for editing contact list.
+        '''
+        contacts = [] + self.values['contact']['ME'] + self.values['contact']['SM']
+        current = self.number.GetValue()
+        dlg = Wammu.EditContactList.EditContactList(self, contacts, current)
+        if dlg.ShowModal() == wx.ID_OK:
+            self.number.SetValue(dlg.GetNumbers())
+
     def OnSend(self, evt = None):
         self.save.Enable(self.send.GetValue())
         self.number.GetValidator().empty = not self.send.GetValue()
@@ -585,7 +601,7 @@ class SMSComposer(wx.Dialog):
         if self.availsel == -1:
             return
         v = {'ID': SMSParts[self.availsel][4]}
-        if v['ID'][-5:] == '16bit' and self.cfg.Read('/Message/16bitId', 'yes') != 'yes':
+        if v['ID'][-5:] == '16bit' and self.cfg.Read('/Message/16bitId') != 'yes':
             v['ID'] = v['ID'][:-5]
         self.StoreEdited()
         self.entry['SMSInfo']['Entries'].insert(self.prevedit + 1, v)
