@@ -1,4 +1,5 @@
 # -*- coding: UTF-8 -*-
+# vim: expandtab sw=4 ts=4 sts=4:
 '''
 Wammu - Phone manager
 Phone information reader
@@ -6,7 +7,7 @@ Phone information reader
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright (c) 2003 - 2006 Michal Čihař
+Copyright (c) 2003 - 2007 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -25,7 +26,6 @@ this program; if not, write to the Free Software Foundation, Inc.,
 import Wammu.Thread
 if Wammu.gammu_error == None:
     import gammu
-from Wammu.Utils import Str_ as _
 
 class GetInfo(Wammu.Thread.Thread):
     def Run(self):
