@@ -1,4 +1,5 @@
 # -*- coding: UTF-8 -*-
+# vim: expandtab sw=4 ts=4 sts=4:
 '''
 Wammu - Phone manager
 Module for writing SMS to Email.
@@ -6,7 +7,7 @@ Module for writing SMS to Email.
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright (c) 2003 - 2006 Michal Čihař
+Copyright (c) 2003 - 2007 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -34,14 +35,31 @@ import time
 import tempfile
 import os
 import wx
-import gammu
 import Wammu.Data
+if Wammu.gammu_error == None:
+    import gammu
+
+HEADER_FORMAT = 'X-Wammu-%s'
+CID_FORMAT = '%d*sms@wammu.sms'
+PARTS_TO_HEADER = [
+        'Folder', 
+        'Memory', 
+        'Location', 
+        'Name', 
+        'Type', 
+        'State', 
+        'Class', 
+        'MessageReference',
+        ]
 
-header_format = 'X-Wammu-%s'
-cid_format = '%d*sms@wammu.sms'
 
 def XPMToPNG(image):
-    # FIXME: I'd like to avoid creating temporary file, but even PIL doesn't seem to provide such functionality
+    '''
+    Convert XPM data to PNG image.
+
+    @todo: I'd like to avoid creating temporary file, but even PIL doesn't
+    seem to provide such functionality.
+    '''
     handle, name = tempfile.mkstemp()
     os.close(handle)
     bitmap = wx.BitmapFromXPMData(image)
@@ -53,7 +71,12 @@ def XPMToPNG(image):
     return data
 
 def RingtoneToMIDI(data):
-    # FIXME: I'd like to avoid creating temporary file, but Gammmu doesn't provide such functionality
+    '''
+    Converts ringtone to MIDI data.
+
+    @todo: I'd like to avoid creating temporary file, but Gammmu doesn't
+    provide such functionality.
+    '''
     handle, name = tempfile.mkstemp()
     f = os.fdopen(handle, 'w+')
     gammu.SaveRingtone(f, data, 'mid')
@@ -63,32 +86,45 @@ def RingtoneToMIDI(data):
     os.unlink(name)
     return data
 
-def DateToString(dt):
-    return email.Utils.formatdate(time.mktime(dt.timetuple()), True)
+def DateToString(date):
+    '''
+    Convert date to RFC 2822 format.
+    '''
+    return email.Utils.formatdate(time.mktime(date.timetuple()), True)
+
 
 def SMSToMail(cfg, sms, lookuplist = None, mailbox = False):
+    '''
+    Converts SMS to formated mail. It will contain all images and sounds from
+    message and predefined animations. Also text formatting is preserved in
+    HTML.
+    '''
     msg = MIMEMultipart('related', None, None, type='text/html')
+    prepend = ''
     name = ''
     if lookuplist != None:
         i = SearchNumber(lookuplist, sms['Number'])
         if i != -1:
-            msg.add_header(header_format % 'ContactID', str(i))
+            msg.add_header(HEADER_FORMAT % 'ContactID', str(i))
             name = '%s ' % lookuplist[i]['Name']
 
-    for header in ['Folder', 'Memory', 'Location', 'Name', 'Type', 'State', 'Class', 'MessageReference']:
-        msg.add_header(header_format % header, unicode(sms['SMS'][0][header]))
-    msg.add_header(header_format % 'SMSC', sms['SMS'][0]['SMSC']['Number'])
+    for header in PARTS_TO_HEADER:
+        msg.add_header(HEADER_FORMAT % header, unicode(sms['SMS'][0][header]))
+    msg.add_header(HEADER_FORMAT % 'SMSC', sms['SMS'][0]['SMSC']['Number'])
     if sms['SMS'][0]['SMSCDateTime'] is not None:
-        msg.add_header(header_format % 'SMSCDate', DateToString(sms['SMS'][0]['SMSCDateTime']))
+        msg.add_header(HEADER_FORMAT % 'SMSCDate', 
+                DateToString(sms['SMS'][0]['SMSCDateTime']))
 
     remote = '%s<%s@wammu.sms>' % (name, sms['Number'])
-    local = 'Wammu <wammu@wammu.sms>' # FIXME: make this configurable?
+    local = cfg.Read('/MesageExport/From')
     if sms['SMS'][0]['Type'] == 'Submit':
         msg['To'] = remote
         msg['From'] = local
     else:
         msg['To'] = local
         msg['From'] = remote
+        prepend = ('Received: from %s via GSM\n' % 
+                unicode(sms['SMS'][0]['SMSC']['Number'])) + prepend
 
     if len(sms['Name']) > 0 :
         msg['Subject'] = SmsTextFormat(cfg, sms['Name'], False)
@@ -106,14 +142,17 @@ def SMSToMail(cfg, sms, lookuplist = None, mailbox = False):
                 if i['Number'] > len(Wammu.Data.PredefinedAnimations):
                     sub = MIMEImage(XPMToPNG(Wammu.Data.UnknownPredefined))
                 else:
-                    sub = MIMEImage(XPMToPNG(Wammu.Data.PredefinedAnimations[i['Number']][1]))
-                sub.add_header('Content-ID', '<%s>' % cid_format % cid)
+                    img = Wammu.Data.PredefinedAnimations[i['Number']][1]
+                    xpm = XPMToPNG(img)
+                    sub = MIMEImage(xpm)
+                sub.add_header('Content-ID', '<%s>' % CID_FORMAT % cid)
                 sub.add_header('Content-Disposition', 'inline')
                 msg.attach(sub)
-                text = text + '<img src="cid:%s">' % (cid_format % cid)
+                text = text + '<img src="cid:%s">' % (CID_FORMAT % cid)
                 cid = cid + 1
 
-            if 0 and i['ID'] in Wammu.Data.SMSIDs['PredefinedSound']: # FIXME: need sounds
+            # FIXME: need sounds
+            if 0 and i['ID'] in Wammu.Data.SMSIDs['PredefinedSound']:
                 if i['Number'] >= len(Wammu.Data.PredefinedSounds):
                     sub = ''
                 else:
@@ -128,46 +167,56 @@ def SMSToMail(cfg, sms, lookuplist = None, mailbox = False):
 
             if i['ID'] in Wammu.Data.SMSIDs['Text']:
                 fmt = '%s'
-                for x in Wammu.Data.TextFormats:
-                    for name, txt, style in x[1:]:
+                for format_data in Wammu.Data.TextFormats:
+                    for name, dummy, style in format_data[1:]:
                         if i.has_key(name) and i[name]:
                             fmt = style % fmt
                 text = text + (fmt % SmsTextFormat(cfg, i['Buffer']))
 
             if i['ID'] in Wammu.Data.SMSIDs['Bitmap']:
-                for x in i['Bitmap']:
-                    sub = MIMEImage(XPMToPNG(x['XPM']))
-                    sub.add_header('Content-ID', '<%s>' % cid_format % cid)
+                for bitmap in i['Bitmap']:
+                    sub = MIMEImage(XPMToPNG(bitmap['XPM']))
+                    sub.add_header('Content-ID', '<%s>' % CID_FORMAT % cid)
                     sub.add_header('Content-Disposition', 'inline')
                     msg.attach(sub)
-                    text = text + '<img src="cid:%s">' % (cid_format % cid)
+                    text = text + '<img src="cid:%s">' % (CID_FORMAT % cid)
                     cid = cid + 1
 
             if i['ID'] in Wammu.Data.SMSIDs['Animation']:
-                for x in i['Bitmap']:
-                    sub = MIMEImage(XPMToPNG(x['XPM']))
-                    sub.add_header('Content-ID', '<%s>' % cid_format % cid)
+                for bitmap in i['Bitmap']:
+                    sub = MIMEImage(XPMToPNG(bitmap['XPM']))
+                    sub.add_header('Content-ID', '<%s>' % CID_FORMAT % cid)
                     sub.add_header('Content-Disposition', 'inline')
                     msg.attach(sub)
-                    text = text + '<img src="cid:%s">' % (cid_format % cid)
+                    text = text + '<img src="cid:%s">' % (CID_FORMAT % cid)
                     cid = cid + 1
 
     else:
         text = SmsTextFormat(cfg, sms['Text'])
 
-    sub = MIMEText('<html><head></head><body>%s</body></html>' % text.encode('utf-8'), 'html', 'utf-8')
+    html = '<html><head></head><body>%s</body></html>'
+    sub = MIMEText(html % text.encode('utf-8'), 'html', 'utf-8')
     msg.attach(sub)
 
     if sms['DateTime'] is not None:
-        filename = '%s-%s-%s.eml' % (sms['SMS'][0]['Type'], sms['DateTime'].strftime("%Y%m%d%H%M%S"), md5.new(sms['Text'].encode('utf-8')).hexdigest())
+        filename = '%s-%s-%s.eml' % (
+                sms['SMS'][0]['Type'], 
+                sms['DateTime'].strftime("%Y%m%d%H%M%S"), 
+                md5.new(sms['Text'].encode('utf-8')).hexdigest())
     else:
-        filename = '%s-%s.eml' % (sms['SMS'][0]['Type'], md5.new(sms['Text'].encode('utf-8')).hexdigest())
+        filename = '%s-%s.eml' % (
+                sms['SMS'][0]['Type'], 
+                md5.new(sms['Text'].encode('utf-8')).hexdigest())
+
+    # Add message ID
+    msg.add_header('Message-ID', '<%s@%s>' % (filename[:-4], sms['Number']))
 
     if mailbox:
-        ts = DateToString(sms['DateTime'])
-        prepend = 'From wammu@wammu.sms %s\n' % ts
-    else:
-        prepend = ''
+        if sms['DateTime'] is None:
+            timestamp = email.Utils.formatdate(None, True)
+        else:
+            timestamp = DateToString(sms['DateTime'])
+        prepend = ('From wammu@wammu.sms %s\n' % timestamp) + prepend
 
     return filename, prepend + msg.as_string()
 
