@@ -37,6 +37,14 @@ import locale
 import Wammu
 import re
 
+# We can use dbus for some fancy stuff
+try:
+    import dbus
+    import dbus.glib
+    HAVE_DBUS = True
+except ImportError:
+    HAVE_DBUS = False
+
 try:
     import gammu
 except SystemError, err:
@@ -69,7 +77,10 @@ import Wammu.ErrorMessage
 import Wammu.TalkbackDialog
 import Wammu.WammuSettings
 import Wammu.SMSExport
-from Wammu.Locales import StrConv
+from Wammu.Locales import StrConv, ConsoleStrConv
+
+TALKBACK_COUNT = 30
+TALKBACK_DAYS = 30
 
 def SortDataKeys(a, b):
     if a == 'info':
@@ -289,8 +300,8 @@ class WammuFrame(wx.Frame):
         menu3.Append(301, _('&Info'), _('Retrieve phone information.'))
         menu3.AppendSeparator()
         menu3.Append(310, _('Contacts (&SIM)'), _('Retrieve contacts from SIM.'))
-        menu3.Append(311, _('Contacts (&phone)'), _('Retrieve contacts from phone memory'))
-        menu3.Append(312, _('&Contacts (All)'), _('Retrieve contacts from phone and SIM memory'))
+        menu3.Append(311, _('Contacts (&phone)'), _('Retrieve contacts from phone memory.'))
+        menu3.Append(312, _('&Contacts (All)'), _('Retrieve contacts from phone and SIM memory.'))
         menu3.AppendSeparator()
         menu3.Append(320, _('C&alls'), _('Retrieve call history.'))
         menu3.AppendSeparator()
@@ -304,7 +315,7 @@ class WammuFrame(wx.Frame):
 
         menu4 = wx.Menu()
         menu4.Append(401, _('&Contact'), _('Create new contact.'))
-        menu4.Append(402, _('&Event'), _('Create new calendar event.'))
+        menu4.Append(402, _('Calendar &event'), _('Create new calendar event.'))
         menu4.Append(403, _('&Todo'), _('Create new todo.'))
         menu4.Append(404, _('&Message'), _('Create new message.'))
         # Add menu to the menu bar
@@ -399,12 +410,14 @@ class WammuFrame(wx.Frame):
             Wammu.ErrorLog.DEBUG_LOG_FILENAME = self.logfilename
 
             if sys.platform != 'win32':
-                print 'Debug log created in %s, in case of crash please include it in bugreport!' % self.logfilename
+                print ConsoleStrConv(
+                    _('Debug log created in temporary file <%s>. In case of crash please include it in bugreport!') % self.logfilename
+                    )
 
             self.logfilefd = os.fdopen(fd, 'w+')
             # use temporary file for logs
             gammu.SetDebugFile(self.logfilefd)
-            gammu.SetDebugLevel('textall')
+            gammu.SetDebugLevel('textalldate')
 
         # initialize variables
         self.showdebug = ''
@@ -464,12 +477,17 @@ class WammuFrame(wx.Frame):
 
     def TalkbackCheck(self):
         '''
-        Do ask for talkback after month of usage.
+        Do ask for talkback after month of usage and at least 30 executions.
         '''
-        if self.cfg.ReadFloat('/Wammu/FirstRun') == -1:
-            self.cfg.WriteFloat('/Wammu/FirstRun', time.time())
+        firstrun = self.cfg.ReadFloat('/Wammu/FirstRun')
+        if firstrun == -1:
+            firstrun = time.time()
+            self.cfg.WriteFloat('/Wammu/FirstRun', firstrun)
+        runs = self.cfg.ReadInt('/Wammu/RunCounter')
+        self.cfg.WriteInt('/Wammu/RunCounter', runs + 1)
         if self.cfg.Read('/Wammu/TalkbackDone') == 'no':
-            if self.cfg.ReadFloat('/Wammu/FirstRun') + (3600 * 24 * 30) < time.time():
+            if (firstrun + (3600 * 24 * TALKBACK_DAYS) < time.time()
+                and runs > TALKBACK_COUNT):
                 dlg = wx.MessageDialog(self,
                     _('You are using Wammu for more than a month. We would like to hear from you how your phone is supported. Do you want to participate in this survey?') +
                     '\n\n' + _('Press Cancel to never show this question again.'),
@@ -501,7 +519,7 @@ class WammuFrame(wx.Frame):
                 self.cfg.gammu.SetConfig(index, device, connection, _('Migrated from older Wammu'), model)
                 self.cfg.WriteInt('/Gammu/Section', index)
 
-    def PostInit(self):
+    def PostInit(self, appparent):
         '''
         Do things which need window opened to behave correctly.
 
@@ -513,6 +531,7 @@ class WammuFrame(wx.Frame):
         - Setup internal information.
         '''
         self.ActivateView('info', '  ')
+        self.appparent = appparent
 
         if Wammu.gammu_error != None:
             self.HandleGammuError()
@@ -536,6 +555,23 @@ class WammuFrame(wx.Frame):
 
         self.SetupTrayIcon()
 
+        self.InitDBUS()
+
+    def InitDBUS(self):
+        '''
+        Initializes DBUS handlers if available.
+        '''
+        self.dbus_notify = None
+        self.last_dbus_id = 0
+        if HAVE_DBUS:
+            bus = dbus.SessionBus() #mainloop = self.appparent.MainLoop)
+            interface = 'org.freedesktop.Notifications'
+            path = '/org/freedesktop/Notifications'
+            if Wammu.Utils.DBUSServiceAvailable(bus, interface, True):
+                obj = bus.get_object(interface, path)
+                self.dbus_notify = dbus.Interface(obj, interface)
+                self.dbus_notify.connect_to_signal('ActionInvoked', self.DBUSActionCallback)
+
     def SetupTrayIcon(self):
         if self.cfg.Read('/Wammu/TaskBarIcon') != 'yes':
             if self.tbicon is not None:
@@ -612,11 +648,17 @@ class WammuFrame(wx.Frame):
                 else:
                     time = StrConv(d.strftime('%c'))
 
-                self.SetStatusText(_('Bat: %(battery_percent)d %% (%(power_source)s), Sig: %(signal_percent)d %%, Time: %(time)s') %
+                # Detect unknown signal quality
+                if s['SignalPercent'] == -1:
+                    signal = _('Unknown')
+                else:
+                    signal = _('%d %%') % s['SignalPercent']
+
+                self.SetStatusText(_('Bat: %(battery_percent)d %% (%(power_source)s), Sig: %(signal_level)s, Time: %(time)s') %
                     {
                         'battery_percent':b['BatteryPercent'],
                         'power_source':power,
-                        'signal_percent':s['SignalPercent'],
+                        'signal_level':signal,
                         'time': time
                     }, 1)
             except gammu.GSMError:
@@ -628,7 +670,7 @@ class WammuFrame(wx.Frame):
             if self.connected:
                 self.prefix = None
                 try:
-                    on = Wammu.Utils.ParseMemoryEntry(self.sm.GetMemory(Location = 1, Type = 'ON'))['Number']
+                    on = Wammu.Utils.ParseMemoryEntry(self.sm.GetMemory(Location = 1, Type = 'ON'), self.cfg)['Number']
                     self.prefix = Wammu.Utils.GrabNumberPrefix(on, Wammu.Data.InternationalPrefixes)
                 except gammu.GSMError:
                     pass
@@ -826,12 +868,18 @@ class WammuFrame(wx.Frame):
             self.tbicon.Destroy()
 
         if sys.platform != 'win32':
-            print 'Looks like normal program termination, deleting log file.'
+            print ConsoleStrConv(
+                _('Looks like normal program termination, deleting log file.')
+                )
         try:
             os.unlink(self.logfilename)
         except:
-            print 'Failed to unlink temporary log file, please delete it yourself'
-            print 'Filename: %s' % self.logfilename
+            print ConsoleStrConv(
+                _('Failed to unlink temporary log file, please delete it yourself.')
+                )
+            print ConsoleStrConv(
+                _('Filename: %s') % self.logfilename
+                )
 
         # Forcibily save configuration
         self.cfg.Flush()
@@ -984,10 +1032,10 @@ class WammuFrame(wx.Frame):
                         if v['Save']:
                             (msg['Location'], msg['Folder']) = self.sm.AddSMS(msg)
                             if v['Send']:
-                                # When sending of saved messages is not supported, send it directly:
+                                # When sending of saved message fails, send it directly:
                                 try:
                                     msg['MessageReference'] = self.sm.SendSavedSMS(0, msg['Location'])
-                                except gammu.ERR_NOTSUPPORTED:
+                                except gammu.GSMError:
                                     msg['MessageReference'] = self.sm.SendSMS(msg)
                             try:
                                 result['SMS'].append(self.sm.GetSMS(0, msg['Location'])[0])
@@ -1023,30 +1071,34 @@ class WammuFrame(wx.Frame):
                 busy = wx.BusyInfo(_('Writing contact...'))
                 time.sleep(0.1)
                 wx.Yield()
-                # was entry moved => delete it
+                # was entry moved => delete it from internal list
                 if not shoulddelete:
-                    # delete from internal list
                     for idx in range(len(self.values['contact'][backup['MemoryType']])):
                         if self.values['contact'][backup['MemoryType']][idx] == v:
                             del self.values['contact'][backup['MemoryType']][idx]
                             break
 
-                    if v['MemoryType'] != backup['MemoryType'] or  v['Location'] != backup['Location']:
-                        # delete from phone
-                        self.sm.DeleteMemory(backup['MemoryType'], backup['Location'])
-
                 # have we specified location? => add or set
                 if v['Location'] == 0:
                     v['Location'] = self.sm.AddMemory(v)
                 else:
-                    v['Location'] = self.sm.SetMemory(v)
+                    try:
+                        v['Location'] = self.sm.SetMemory(v)
+                    except (gammu.ERR_NOTSUPPORTED, gammu.ERR_NOTIMPLEMENTED):
+                        v['Location'] = self.sm.AddMemory(v)
+
+                # was entry moved => delete it from phone
+                if not shoulddelete:
+                    if v['MemoryType'] != backup['MemoryType'] or  v['Location'] != backup['Location']:
+                        # delete from phone
+                        self.sm.DeleteMemory(backup['MemoryType'], backup['Location'])
 
                 # reread entry (it doesn't have to contain exactly same data as entered, it depends on phone features)
                 try:
                     v = self.sm.GetMemory(v['MemoryType'], v['Location'])
                 except (gammu.ERR_NOTSUPPORTED, gammu.ERR_NOTIMPLEMENTED):
                     wx.MessageDialog(self, _('It was not possible to read saved entry! It might be different than one saved in phone untill you reread all entries.'), _('Could not read saved entry!'), wx.OK | wx.ICON_WARNING).ShowModal()
-                Wammu.Utils.ParseMemoryEntry(v)
+                Wammu.Utils.ParseMemoryEntry(v, self.cfg)
                 v['Synced'] = True
                 # append new value to list
                 self.values['contact'][v['MemoryType']].append(v)
@@ -1077,7 +1129,7 @@ class WammuFrame(wx.Frame):
                 busy = wx.BusyInfo(_('Writing calendar...'))
                 time.sleep(0.1)
                 wx.Yield()
-                # was entry moved => delete it
+                # was entry moved => delete it from internal list
                 if not shoulddelete:
                     # delete from internal list
                     for idx in range(len(self.values['calendar']['  '])):
@@ -1085,15 +1137,20 @@ class WammuFrame(wx.Frame):
                             del self.values['calendar']['  '][idx]
                             break
 
-                    if v['Location'] != backup['Location']:
-                        # delete from phone
-                        self.sm.DeleteCalendar(backup['Location'])
-
                 # have we specified location? => add or set
                 if v['Location'] == 0:
                     v['Location'] = self.sm.AddCalendar(v)
                 else:
-                    v['Location'] = self.sm.SetCalendar(v)
+                    try:
+                        v['Location'] = self.sm.SetCalendar(v)
+                    except (gammu.ERR_NOTSUPPORTED, gammu.ERR_NOTIMPLEMENTED):
+                        v['Location'] = self.sm.AddCalendar(v)
+
+                # was entry moved => delete it from phone
+                if not shoulddelete:
+                    if v['Location'] != backup['Location']:
+                        # delete from phone
+                        self.sm.DeleteCalendar(backup['Location'])
 
                 # reread entry (it doesn't have to contain exactly same data as entered, it depends on phone features)
                 try:
@@ -1124,23 +1181,27 @@ class WammuFrame(wx.Frame):
                 busy = wx.BusyInfo(_('Writing todo...'))
                 time.sleep(0.1)
                 wx.Yield()
-                # was entry moved => delete it
+                # was entry moved => delete it from internal list
                 if not shoulddelete:
-                    # delete from internal list
                     for idx in range(len(self.values['todo']['  '])):
                         if self.values['todo']['  '][idx] == v:
                             del self.values['todo']['  '][idx]
                             break
 
-                    if v['Location'] != backup['Location']:
-                        # delete from phone
-                        self.sm.DeleteToDo(backup['Location'])
-
                 # have we specified location? => add or set
                 if v['Location'] == 0:
                     v['Location'] = self.sm.AddToDo(v)
                 else:
-                    v['Location'] = self.sm.SetToDo(v)
+                    try:
+                        v['Location'] = self.sm.SetToDo(v)
+                    except (gammu.ERR_NOTSUPPORTED, gammu.ERR_NOTIMPLEMENTED):
+                        v['Location'] = self.sm.AddToDo(v)
+
+                # was entry moved => delete it from phone
+                if not shoulddelete:
+                    if v['Location'] != backup['Location']:
+                        # delete from phone
+                        self.sm.DeleteToDo(backup['Location'])
 
                 # reread entry (it doesn't have to contain exactly same data as entered, it depends on phone features)
                 try:
@@ -1277,7 +1338,7 @@ class WammuFrame(wx.Frame):
                 wildcard += _('vCard [contacts]') + ' (*.vcf)|*.vcf|'
                 exts.append('vcf')
             if type in ['contact', 'all']:
-                wildcard += _('LDIF [concacts]') + ' (*.ldif)|*.ldif|'
+                wildcard += _('LDIF [contacts]') + ' (*.ldif)|*.ldif|'
                 exts.append('ldif')
             if type in ['todo', 'calendar', 'all']:
                 wildcard += _('vCalendar [todo,calendar]') + ' (*.vcs)|*.vcs|'
@@ -1337,9 +1398,9 @@ class WammuFrame(wx.Frame):
             return
 
         if len(backup['PhonePhonebook']) > 0:
-            self.values['contact']['ME'] = map(Wammu.Utils.ParseMemoryEntry, backup['PhonePhonebook'])
+            self.values['contact']['ME'] = map(Wammu.Utils.ParseMemoryEntry, backup['PhonePhonebook'], [self.cfg] * len(backup['PhonePhonebook']))
         if len(backup['SIMPhonebook']) > 0:
-            self.values['contact']['SM'] = map(Wammu.Utils.ParseMemoryEntry, backup['SIMPhonebook'])
+            self.values['contact']['SM'] = map(Wammu.Utils.ParseMemoryEntry, backup['SIMPhonebook'], [self.cfg] * len(backup['SIMPhonebook']))
         if len(backup['ToDo']) > 0:
             self.values['todo']['  '] = map(Wammu.Utils.ParseTodo, backup['ToDo'])
         if len(backup['Calendar']) > 0:
@@ -1482,7 +1543,7 @@ class WammuFrame(wx.Frame):
                         v['Location'] = self.sm.AddMemory(v)
                         # reread entry (it doesn't have to contain exactly same data as entered, it depends on phone features)
                         v = self.sm.GetMemory(v['MemoryType'], v['Location'])
-                        Wammu.Utils.ParseMemoryEntry(v)
+                        Wammu.Utils.ParseMemoryEntry(v, self.cfg)
                         v['Synced'] = True
                         # append new value to list
                         self.values['contact'][v['MemoryType']].append(v)
@@ -1492,7 +1553,7 @@ class WammuFrame(wx.Frame):
                         v['Location'] = self.sm.AddMemory(v)
                         # reread entry (it doesn't have to contain exactly same data as entered, it depends on phone features)
                         v = self.sm.GetMemory(v['MemoryType'], v['Location'])
-                        Wammu.Utils.ParseMemoryEntry(v)
+                        Wammu.Utils.ParseMemoryEntry(v, self.cfg)
                         v['Synced'] = True
                         # append new value to list
                         self.values['contact'][v['MemoryType']].append(v)
@@ -1646,30 +1707,45 @@ class WammuFrame(wx.Frame):
 
         # check for confirmation
         if self.cfg.Read('/Wammu/ConfirmDelete') == 'yes':
-            txt = _('Are you sure you want to delete %s?')
-            if len(lst) == 1:
+            count = len(lst)
+            if count == 1:
                 v = lst[0]
                 if self.type[0] == 'contact':
-                    txt = txt % (_('contact "%s"') % v['Name'])
+                    txt = _('Are you sure you want to delete contact "%s"?') % v['Name']
                 elif self.type[0] == 'call':
-                    txt = txt % (_('call "%s"') % v['Name'])
+                    txt = _('Are you sure you want to delete call from "%s"?') % v['Name']
                 elif self.type[0] == 'message':
-                    txt = txt % (_('message from "%s"') % v['Number'])
+                    txt = _('Are you sure you want to delete message from "%s"?') % v['Number']
                 elif self.type[0] == 'todo':
-                    txt = txt % (_('todo "%s"') % v['Text'])
+                    txt = _('Are you sure you want to delete todo entry "%s"?') % v['Text']
                 elif self.type[0] == 'calendar':
-                    txt = txt % (_('calendar entry "%s"') % v['Text'])
+                    txt = _('Are you sure you want to delete calendar entry "%s"?') % v['Text']
             else:
                 if self.type[0] == 'contact':
-                    txt = txt % (_('%d contacts') % len(lst))
+                    txt = Wammu.Locales.ngettext(
+                            'Are you sure you want to delete %d contact?',
+                            'Are you sure you want to delete %d contacts?',
+                            count) % count
                 elif self.type[0] == 'call':
-                    txt = txt % (_('%d calls') % len(lst))
+                    txt = Wammu.Locales.ngettext(
+                            'Are you sure you want to delete %d call?',
+                            'Are you sure you want to delete %d calls?',
+                            count) % count
                 elif self.type[0] == 'message':
-                    txt = txt % (_('%d messages') % len(lst))
+                    txt = Wammu.Locales.ngettext(
+                            'Are you sure you want to delete %d message?',
+                            'Are you sure you want to delete %d messages?',
+                            count) % count
                 elif self.type[0] == 'todo':
-                    txt = txt % (_('%d todo') % len(lst))
+                    txt = Wammu.Locales.ngettext(
+                            'Are you sure you want to delete %d todo entry?',
+                            'Are you sure you want to delete %d todo entries?',
+                            count) % count
                 elif self.type[0] == 'calendar':
-                    txt = txt % (_('%d calendar entries') % len(lst))
+                    txt = Wammu.Locales.ngettext(
+                            'Are you sure you want to delete %d calendar entry?',
+                            'Are you sure you want to delete %d calendar entries?',
+                            count) % count
             dlg = wx.MessageDialog(self,
                 txt,
                 _('Confirm deleting'),
@@ -1920,6 +1996,11 @@ class WammuFrame(wx.Frame):
                 try:
                     while (not file_f['Finished']):
                         file_f = self.sm.SendFilePart(file_f)
+                except gammu.ERR_PERMISSION:
+                    wx.MessageDialog(self,
+                        _('Transfer has been rejected by phone.'),
+                        _('Transfer rejected!'),
+                        wx.OK | wx.ICON_ERROR).ShowModal()
                 except gammu.GSMError, val:
                     del busy
                     self.ShowError(val[0])
@@ -1946,7 +2027,7 @@ class WammuFrame(wx.Frame):
             'SyncTime': self.cfg.Read('/Gammu/SyncTime'),
             'Connection': config['Connection'],
             'LockDevice': self.cfg.Read('/Gammu/LockDevice'),
-            'DebugLevel': 'textall', # Set on other place
+            'DebugLevel': 'textalldate', # Set on other place
             'Device': config['Device'],
             'Localize': None,  # Set automatically by python-gammu
             'Model': config['Model'],
@@ -1956,6 +2037,8 @@ class WammuFrame(wx.Frame):
         self.sm.SetConfig(0, cfg)
         try:
             self.sm.Init()
+            self.sm.SetIncomingCallback(self.IncomingEvent)
+            self.sm.SetIncomingCall(True)
             self.TogglePhoneMenus(True)
             self.SetupNumberPrefix()
             try:
@@ -1989,6 +2072,44 @@ class WammuFrame(wx.Frame):
             except gammu.GSMError, val:
                 pass
 
+    def DBUSActionCallback(self, id, action):
+        '''
+        Called when user does something on notification.
+        '''
+        self.dbus_notify.CloseNotification(self.last_dbus_id)
+        if action == 'accept-call':
+            self.sm.AnswerCall(0, True)
+        elif action == 'reject-call':
+            self.sm.CancelCall(0, True)
+        else:
+            print 'Unknown DBUS event: %s' % action
+
+    def DBUSNotify(self, title, message, actions):
+        '''
+        Performs D-Bus notification if available.
+        '''
+        if self.dbus_notify is not None:
+            self.last_dbus_id = self.dbus_notify.Notify(
+                    'Wammu', self.last_dbus_id, 'wammu',
+                    title, message, actions, {}, -1)
+
+
+    def IncomingEvent(self, sm, type, data):
+        '''
+        Called on incoming event from phone.
+        '''
+
+        if type == 'Call':
+            if data['Status'] != 'IncomingCall':
+                # We care only about incoming calls
+                return
+            if data['Number'] == '':
+                msg = _('Your phone has just received incoming call')
+            else:
+                msg = _('Your phone has just received incoming call from %s') % data['Number']
+            self.DBUSNotify(_('Incoming call'), msg,
+                    ['reject-call', _('Reject'), 'accept-call', _('Accept')])
+
     def PhoneDisconnect(self, event = None):
         busy = wx.BusyInfo(_('One moment please, disconnecting from phone...'))
         time.sleep(0.1)
