@@ -1,4 +1,5 @@
 # -*- coding: UTF-8 -*-
+# vim: expandtab sw=4 ts=4 sts=4:
 '''
 Wammu - Phone manager
 Message to HTML conversion
@@ -6,7 +7,7 @@ Message to HTML conversion
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright (c) 2003 - 2006 Michal Čihař
+Copyright (c) 2003 - 2007 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -27,10 +28,11 @@ import Wammu.Data
 import Wammu.Ringtone
 import string
 import re
-from Wammu.Utils import UnicodeConv, HtmlStr_ as _, HtmlStrConv
+import xml.sax.saxutils
+from Wammu.Locales import UnicodeConv, HtmlStrConv, hgettext as _
 
 def SmsTextFormat(cfg, txt, dohtml = True):
-    if cfg.Read('/Wammu/FormatSMS', 'yes') == 'yes':
+    if cfg.Read('/Message/Format') == 'yes':
         ret = ''
         arr = txt.split(' ')
         for a in arr:
@@ -87,7 +89,8 @@ def SmsTextFormat(cfg, txt, dohtml = True):
     else:
         ret = txt
     if dohtml:
-        return ret.replace('\n', '<br>')
+        xmlsafe = xml.sax.saxutils.escape(ret)
+        return xmlsafe.replace('\n', '<br>')
     else:
         return ret.replace('\n', ' ')
 
@@ -142,7 +145,7 @@ def SmsToHtml(cfg, v):
                 x = i['Bitmap'][0]
                 text = text + \
                     '<wxp module="Wammu.Image" class="Bitmap">' + \
-                    '<param name="scale" value="(' + str(cfg.ReadInt('/Message/ScaleImage', 1)) + ')">' + \
+                    '<param name="scale" value="(' + str(cfg.ReadInt('/Message/ScaleImage')) + ')">' + \
                     '<param name="image" value="' + "['" + string.join(x['XPM'], "', '") + "']" + '">' + \
                     '</wxp>'
 
@@ -152,7 +155,7 @@ def SmsToHtml(cfg, v):
                     data.append("['" + string.join(x['XPM'], "', '") + "']")
                     text = text + \
                         '<wxp module="Wammu.Image" class="Throbber">' + \
-                        '<param name="scale" value="(' + str(cfg.ReadInt('/Message/ScaleImage', 1)) + ')">' + \
+                        '<param name="scale" value="(' + str(cfg.ReadInt('/Message/ScaleImage')) + ')">' + \
                         '<param name="images" value="' + "['" + string.join(data, "', '") + "']" + '">' + \
                         '</wxp>'
         if v['SMSInfo'].has_key('Unknown') and v['SMSInfo']['Unknown']:
