@@ -1,4 +1,5 @@
 # -*- coding: UTF-8 -*-
+# vim: expandtab sw=4 ts=4 sts=4:
 '''
 Wammu - Phone manager
 Data path definition and misc path functions
@@ -6,7 +7,7 @@ Data path definition and misc path functions
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright (c) 2003 - 2006 Michal Čihař
+Copyright (c) 2003 - 2007 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -26,12 +27,11 @@ import os
 import os.path
 import sys
 
-datapath = os.path.join(sys.exec_prefix, 'share', 'Wammu')
-if not os.path.exists(os.path.join(datapath, 'images')):
-    if not os.path.exists('images'):
+DATAPATH = os.path.join(os.path.dirname(__file__), '..')
+if not os.path.exists(os.path.join(DATAPATH, 'images')):
+    DATAPATH = os.path.join(sys.exec_prefix, 'share', 'Wammu')
+    if not os.path.exists(os.path.join(DATAPATH, 'images')):
         print 'Could not find images, you will not see them, check your installation!'
-    else:
-        datapath = os.getcwd()
 
 def AppIconPath(*args):
     if sys.platform == 'win32':
@@ -51,4 +51,4 @@ def MiscPath(*args):
     return ImagePath('misc', *args)
 
 def ImagePath(*args):
-    return os.path.join(datapath, 'images', *args) + os.extsep + 'png'
+    return os.path.join(DATAPATH, 'images', *args) + os.extsep + 'png'
