@@ -50,7 +50,7 @@ class PhoneValidator(wx.PyValidator):
         self.multi = multi
         self.pause = pause
         self.empty = empty
-        wx.EVT_CHAR(self, self.OnChar)
+        self.Bind(wx.EVT_CHAR, self.OnChar)
 
     def Clone(self):
         return PhoneValidator(self.multi, self.pause, self.empty)
@@ -62,6 +62,9 @@ class PhoneValidator(wx.PyValidator):
         return True
 
     def CheckText(self, text, immediate = False):
+        '''
+        Verifies whether enterd text is correct.
+        '''
         if self.multi:
             values = SplitNumbers(text)
         else:
@@ -69,13 +72,12 @@ class PhoneValidator(wx.PyValidator):
         for val in values:
             if val == '':
                 result = self.empty
-            elif not immediate or val != '+':
-                if self.pause:
-                    if MATCHER_PAUSE.match(val) == None:
-                        return False
-                else:
-                    if MATCHER_NORMAL.match(val) == None:
-                        return False
+            elif self.pause and MATCHER_PAUSE.match(val) == None:
+                return False
+            elif not self.pause and MATCHER_NORMAL.match(val) == None:
+                return False
+            elif immediate and val == '+':
+                continue
         return True
 
     def Validate(self, win = None):
@@ -97,12 +99,12 @@ class PhoneValidator(wx.PyValidator):
         key = event.GetKeyCode()
 
         # control chars
-        if (key < wx.WXK_SPACE or 
-                key == wx.WXK_DELETE or 
-                key > 255 or 
-                event.AltDown() or 
-                event.CmdDown() or 
-                event.ControlDown() or 
+        if (key < wx.WXK_SPACE or
+                key == wx.WXK_DELETE or
+                key > 255 or
+                event.AltDown() or
+                event.CmdDown() or
+                event.ControlDown() or
                 event.MetaDown()):
             event.Skip()
             return
