@@ -1,4 +1,5 @@
 # -*- coding: UTF-8 -*-
+# vim: expandtab sw=4 ts=4 sts=4:
 '''
 Wammu - Phone manager
 Ringtone displaying and playback
@@ -6,7 +7,7 @@ Ringtone displaying and playback
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright (c) 2003 - 2006 Michal Čihař
+Copyright (c) 2003 - 2007 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -30,7 +31,6 @@ if Wammu.gammu_error == None:
 import os
 import thread
 import commands
-from Wammu.Utils import Str_ as _
 
 ringtones = {}
 
