@@ -29,6 +29,12 @@ import sys
 import re
 import wx
 import string
+import os
+try:
+    import grp
+    HAVE_GRP = True
+except ImportError:
+    HAVE_GRP = False
 import Wammu.Locales
 from Wammu.Locales import StrConv
 
@@ -126,12 +132,25 @@ NumberPrefix = ''
 NumberStrip = re.compile('^([#*]\d+[#*])?(\\+?.*)$')
 
 def NormalizeNumber(number):
+    '''
+    Attempts to create international number from anything it receives.
+    It does strip any network prefixes and attempts to properly add
+    international prefix. However this is a bit tricky, as there are
+    many ways which can break this.
+    '''
     # Strip magic prefixes (like no CLIR)
     nbmatch = NumberStrip.match(number)
     resnumber = nbmatch.group(2)
     # If we stripped whole number, return original
     if len(resnumber) == 0:
         return number
+    # Handle 00 prefix same as +
+    if resnumber[0:2] == '00':
+        resnumber = '+' + resnumber[2:]
+    # Detect numbers with international prefix and without +
+    # This can be national number in some countries (eg. US)
+    if NumberPrefix[0] == '+' and resnumber[:len(NumberPrefix) - 1] == NumberPrefix[1:]:
+        resnumber = '+' + resnumber
     # Add international prefix
     if resnumber[0] != '+':
         resnumber = NumberPrefix + resnumber
@@ -175,10 +194,12 @@ def GetTypeString(type, value, values, linkphone = True):
     else:
         return StrConv(value)
 
-def ParseMemoryEntry(entry):
+def ParseMemoryEntry(entry, config = None):
     first = ''
     last = ''
     name = ''
+    nickname = ''
+    formalname = ''
     company = ''
     number = ''
     number_result = ''
@@ -191,6 +212,10 @@ def ParseMemoryEntry(entry):
             first = i['Value']
         if i['Type'] == 'Text_LastName':
             last = i['Value']
+        if i['Type'] == 'Text_NickName':
+            nickname = i['Value']
+        if i['Type'] == 'Text_FormalName':
+            formalname = i['Value']
         if i['Type'] == 'Date':
             date = i['Value']
         if i['Type'] == 'Text_Company':
@@ -199,25 +224,56 @@ def ParseMemoryEntry(entry):
             number_result = i['Value']
         elif i['Type'][:7] == 'Number_':
             number =  i['Value']
-    if name != '':
-        name_result = name
-    elif first != '':
-        if last != '':
-            name_result = last + ', ' + first
-        else:
-            name_result = first
-    elif last != '':
-        name_result = last
-    elif company != '':
-        name_result = company
+
+    if config is None:
+        format = 'auto'
     else:
-        name_result = ''
+        format = config.Read('/Wammu/NameFormat')
+
+    if format == 'custom':
+        name_result = config.Read('/Wammu/NameFormatString') % {
+                'Name' : name,
+                'FirstName' : first,
+                'LastName' : last,
+                'NickName' : nickname,
+                'FormalName' : formalname,
+                'Company' : company,
+                }
+    else:
+        if name != '':
+            name_result = name
+        elif first != '':
+            if last != '':
+                if format == 'auto-first-last':
+                    name_result = '%s %s' % (first, last)
+                else:
+                    name_result = '%s, %s' % (last, first)
+            else:
+                name_result = first
+        elif last != '':
+            name_result = last
+        elif nickname != '':
+            name_result = nickname
+        elif formalname != '':
+            name_result = formalname
+        else:
+            name_result = ''
+
+        if name_result == '':
+            if company != '':
+                name_result = company
+        else:
+            if company != '':
+                name_result = '%s (%s)' % (name_result, company)
+
     if number_result == '':
         number_result = number
+
     entry['Number'] = number_result
     entry['Name'] = name_result
     entry['Synced'] = False
     entry['Date'] = date
+
     return entry
 
 def ParseTodo(entry):
@@ -411,3 +467,50 @@ def GetWebsiteLang():
     except TypeError:
         return ''
 
+def DBUSServiceAvailable(bus, interface, try_start_service=False):
+    try:
+        import dbus
+    except ImportError:
+        return False
+    if try_start_service:
+        try:
+            bus.start_service_by_name(interface)
+        except dbus.exceptions.DBusException:
+            print 'Failed to start DBus service %s' % interface
+    obj = bus.get_object('org.freedesktop.DBus', '/org/freedesktop/DBus')
+    dbus_iface = dbus.Interface(obj, 'org.freedesktop.DBus')
+    avail = dbus_iface.ListNames()
+    return interface in avail
+
+
+def CheckDeviceNode(curdev):
+    '''
+    Checks whether it makes sense to perform searching on this device and
+    possibly warns user about misconfigurations.
+
+    Returns tuple of 4 members:
+    - error code (0 = ok, -1 = device does not exits, -2 = no permissions)
+    - log text
+    - error dialog title
+    - error dialog text
+    '''
+    if not os.path.exists(curdev):
+        return (-1,
+                _('Device %s does not exist!') % curdev,
+                _('Error opening device'),
+                _('Device %s does not exist!') % curdev
+                )
+    if not os.access(curdev, os.R_OK) or not os.access(curdev, os.W_OK):
+        gid =  os.stat(curdev).st_gid
+        if HAVE_GRP:
+            group = grp.getgrgid(gid)[0]
+        else:
+            group = str(gid)
+        return (-2,
+                _('You don\'t have permissions for %s device!') % curdev,
+                _('Error opening device'),
+                (_('You don\'t have permissions for %s device!') % curdev) +
+                ' ' +
+                (_('Maybe you need to be member of %s group.') % group)
+                )
+    return (0, '', '', '')
